<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>EditFromReference</name>
    <message>
        <location filename="../EditFromReference.js" line="+55"/>
        <source>Choose block reference</source>
        <translation>Choisissez la référence du bloc</translation>
    </message>
    <message>
        <location filename="../EditFromReferenceInit.js" line="+2"/>
        <source>E&amp;dit Block from Reference</source>
        <translation>M&amp;odifier le bloc à partir d&apos;une référence</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Edit block based on chosen block reference</source>
        <translation>Modifier un bloc basé sur une référence de bloc choisie</translation>
    </message>
</context>
</TS>
